# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDomainResult',
    'AwaitableGetDomainResult',
    'get_domain',
    'get_domain_output',
]

@pulumi.output_type
class GetDomainResult:
    """
    A collection of values returned by getDomain.
    """
    def __init__(__self__, certificate_source_type=None, dns_records=None, domain=None, domain_id_or_name=None, id=None, public_certificate=None, validation_status=None):
        if certificate_source_type and not isinstance(certificate_source_type, str):
            raise TypeError("Expected argument 'certificate_source_type' to be a str")
        pulumi.set(__self__, "certificate_source_type", certificate_source_type)
        if dns_records and not isinstance(dns_records, list):
            raise TypeError("Expected argument 'dns_records' to be a list")
        pulumi.set(__self__, "dns_records", dns_records)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if domain_id_or_name and not isinstance(domain_id_or_name, str):
            raise TypeError("Expected argument 'domain_id_or_name' to be a str")
        pulumi.set(__self__, "domain_id_or_name", domain_id_or_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if public_certificate and not isinstance(public_certificate, dict):
            raise TypeError("Expected argument 'public_certificate' to be a dict")
        pulumi.set(__self__, "public_certificate", public_certificate)
        if validation_status and not isinstance(validation_status, str):
            raise TypeError("Expected argument 'validation_status' to be a str")
        pulumi.set(__self__, "validation_status", validation_status)

    @_builtins.property
    @pulumi.getter(name="certificateSourceType")
    def certificate_source_type(self) -> _builtins.str:
        """
        Certificate source type that indicates whether the certificate is provided by the user or Okta. Values: MANUAL, OKTA_MANAGED
        """
        return pulumi.get(self, "certificate_source_type")

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> Sequence['outputs.GetDomainDnsRecordResult']:
        """
        TXT and CNAME records to be registered for the Domain
        """
        return pulumi.get(self, "dns_records")

    @_builtins.property
    @pulumi.getter
    def domain(self) -> _builtins.str:
        """
        Domain name
        """
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter(name="domainIdOrName")
    def domain_id_or_name(self) -> _builtins.str:
        """
        Brand ID
        """
        return pulumi.get(self, "domain_id_or_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the Domain
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="publicCertificate")
    def public_certificate(self) -> Mapping[str, _builtins.str]:
        """
        Certificate metadata for the Domain
        """
        return pulumi.get(self, "public_certificate")

    @_builtins.property
    @pulumi.getter(name="validationStatus")
    def validation_status(self) -> _builtins.str:
        """
        Status of the domain. Values: NOT*STARTED, IN*PROGRESS, VERIFIED, COMPLETED
        """
        return pulumi.get(self, "validation_status")


class AwaitableGetDomainResult(GetDomainResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainResult(
            certificate_source_type=self.certificate_source_type,
            dns_records=self.dns_records,
            domain=self.domain,
            domain_id_or_name=self.domain_id_or_name,
            id=self.id,
            public_certificate=self.public_certificate,
            validation_status=self.validation_status)


def get_domain(domain_id_or_name: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainResult:
    """
    Get a domain from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.Domain("example", name="www.example.com")
    by_name = okta.get_domain(domain_id_or_name="www.example.com")
    by_id = okta.get_domain_output(domain_id_or_name=example.id)
    ```


    :param _builtins.str domain_id_or_name: Brand ID
    """
    __args__ = dict()
    __args__['domainIdOrName'] = domain_id_or_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getDomain:getDomain', __args__, opts=opts, typ=GetDomainResult).value

    return AwaitableGetDomainResult(
        certificate_source_type=pulumi.get(__ret__, 'certificate_source_type'),
        dns_records=pulumi.get(__ret__, 'dns_records'),
        domain=pulumi.get(__ret__, 'domain'),
        domain_id_or_name=pulumi.get(__ret__, 'domain_id_or_name'),
        id=pulumi.get(__ret__, 'id'),
        public_certificate=pulumi.get(__ret__, 'public_certificate'),
        validation_status=pulumi.get(__ret__, 'validation_status'))
def get_domain_output(domain_id_or_name: Optional[pulumi.Input[_builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDomainResult]:
    """
    Get a domain from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.Domain("example", name="www.example.com")
    by_name = okta.get_domain(domain_id_or_name="www.example.com")
    by_id = okta.get_domain_output(domain_id_or_name=example.id)
    ```


    :param _builtins.str domain_id_or_name: Brand ID
    """
    __args__ = dict()
    __args__['domainIdOrName'] = domain_id_or_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getDomain:getDomain', __args__, opts=opts, typ=GetDomainResult)
    return __ret__.apply(lambda __response__: GetDomainResult(
        certificate_source_type=pulumi.get(__response__, 'certificate_source_type'),
        dns_records=pulumi.get(__response__, 'dns_records'),
        domain=pulumi.get(__response__, 'domain'),
        domain_id_or_name=pulumi.get(__response__, 'domain_id_or_name'),
        id=pulumi.get(__response__, 'id'),
        public_certificate=pulumi.get(__response__, 'public_certificate'),
        validation_status=pulumi.get(__response__, 'validation_status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ServerPolicyArgs', 'ServerPolicy']

@pulumi.input_type
class ServerPolicyArgs:
    def __init__(__self__, *,
                 auth_server_id: pulumi.Input[_builtins.str],
                 client_whitelists: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 description: pulumi.Input[_builtins.str],
                 priority: pulumi.Input[_builtins.int],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ServerPolicy resource.
        :param pulumi.Input[_builtins.str] auth_server_id: The ID of the Auth Server.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] client_whitelists: The clients to whitelist the policy for. `[ALL_CLIENTS]` is a special value that can be used to whitelist all clients, otherwise it is a list of client ids.
        :param pulumi.Input[_builtins.str] description: The description of the Auth Server Policy.
        :param pulumi.Input[_builtins.int] priority: Priority of the auth server policy
        :param pulumi.Input[_builtins.str] name: The name of the Auth Server Policy.
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        """
        pulumi.set(__self__, "auth_server_id", auth_server_id)
        pulumi.set(__self__, "client_whitelists", client_whitelists)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "priority", priority)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Auth Server.
        """
        return pulumi.get(self, "auth_server_id")

    @auth_server_id.setter
    def auth_server_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "auth_server_id", value)

    @_builtins.property
    @pulumi.getter(name="clientWhitelists")
    def client_whitelists(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        The clients to whitelist the policy for. `[ALL_CLIENTS]` is a special value that can be used to whitelist all clients, otherwise it is a list of client ids.
        """
        return pulumi.get(self, "client_whitelists")

    @client_whitelists.setter
    def client_whitelists(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "client_whitelists", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Input[_builtins.str]:
        """
        The description of the Auth Server Policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Input[_builtins.int]:
        """
        Priority of the auth server policy
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Auth Server Policy.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default to `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _ServerPolicyState:
    def __init__(__self__, *,
                 auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 client_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServerPolicy resources.
        :param pulumi.Input[_builtins.str] auth_server_id: The ID of the Auth Server.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] client_whitelists: The clients to whitelist the policy for. `[ALL_CLIENTS]` is a special value that can be used to whitelist all clients, otherwise it is a list of client ids.
        :param pulumi.Input[_builtins.str] description: The description of the Auth Server Policy.
        :param pulumi.Input[_builtins.str] name: The name of the Auth Server Policy.
        :param pulumi.Input[_builtins.int] priority: Priority of the auth server policy
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        """
        if auth_server_id is not None:
            pulumi.set(__self__, "auth_server_id", auth_server_id)
        if client_whitelists is not None:
            pulumi.set(__self__, "client_whitelists", client_whitelists)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Auth Server.
        """
        return pulumi.get(self, "auth_server_id")

    @auth_server_id.setter
    def auth_server_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_server_id", value)

    @_builtins.property
    @pulumi.getter(name="clientWhitelists")
    def client_whitelists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The clients to whitelist the policy for. `[ALL_CLIENTS]` is a special value that can be used to whitelist all clients, otherwise it is a list of client ids.
        """
        return pulumi.get(self, "client_whitelists")

    @client_whitelists.setter
    def client_whitelists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "client_whitelists", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the Auth Server Policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Auth Server Policy.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Priority of the auth server policy
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default to `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("okta:auth/serverPolicy:ServerPolicy")
class ServerPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 client_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates an Authorization Server Policy. This resource allows you to create and configure an Authorization Server Policy.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.auth.ServerPolicy("example",
            auth_server_id="<auth server id>",
            status="ACTIVE",
            name="example",
            description="example",
            priority=1,
            client_whitelists=["ALL_CLIENTS"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:auth/serverPolicy:ServerPolicy example <auth_server_id>/<policy_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_server_id: The ID of the Auth Server.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] client_whitelists: The clients to whitelist the policy for. `[ALL_CLIENTS]` is a special value that can be used to whitelist all clients, otherwise it is a list of client ids.
        :param pulumi.Input[_builtins.str] description: The description of the Auth Server Policy.
        :param pulumi.Input[_builtins.str] name: The name of the Auth Server Policy.
        :param pulumi.Input[_builtins.int] priority: Priority of the auth server policy
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServerPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an Authorization Server Policy. This resource allows you to create and configure an Authorization Server Policy.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.auth.ServerPolicy("example",
            auth_server_id="<auth server id>",
            status="ACTIVE",
            name="example",
            description="example",
            priority=1,
            client_whitelists=["ALL_CLIENTS"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:auth/serverPolicy:ServerPolicy example <auth_server_id>/<policy_id>
        ```

        :param str resource_name: The name of the resource.
        :param ServerPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServerPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 client_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServerPolicyArgs.__new__(ServerPolicyArgs)

            if auth_server_id is None and not opts.urn:
                raise TypeError("Missing required property 'auth_server_id'")
            __props__.__dict__["auth_server_id"] = auth_server_id
            if client_whitelists is None and not opts.urn:
                raise TypeError("Missing required property 'client_whitelists'")
            __props__.__dict__["client_whitelists"] = client_whitelists
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if priority is None and not opts.urn:
                raise TypeError("Missing required property 'priority'")
            __props__.__dict__["priority"] = priority
            __props__.__dict__["status"] = status
        super(ServerPolicy, __self__).__init__(
            'okta:auth/serverPolicy:ServerPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
            client_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            priority: Optional[pulumi.Input[_builtins.int]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'ServerPolicy':
        """
        Get an existing ServerPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_server_id: The ID of the Auth Server.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] client_whitelists: The clients to whitelist the policy for. `[ALL_CLIENTS]` is a special value that can be used to whitelist all clients, otherwise it is a list of client ids.
        :param pulumi.Input[_builtins.str] description: The description of the Auth Server Policy.
        :param pulumi.Input[_builtins.str] name: The name of the Auth Server Policy.
        :param pulumi.Input[_builtins.int] priority: Priority of the auth server policy
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServerPolicyState.__new__(_ServerPolicyState)

        __props__.__dict__["auth_server_id"] = auth_server_id
        __props__.__dict__["client_whitelists"] = client_whitelists
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["priority"] = priority
        __props__.__dict__["status"] = status
        return ServerPolicy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Auth Server.
        """
        return pulumi.get(self, "auth_server_id")

    @_builtins.property
    @pulumi.getter(name="clientWhitelists")
    def client_whitelists(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The clients to whitelist the policy for. `[ALL_CLIENTS]` is a special value that can be used to whitelist all clients, otherwise it is a list of client ids.
        """
        return pulumi.get(self, "client_whitelists")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        The description of the Auth Server Policy.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Auth Server Policy.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Output[_builtins.int]:
        """
        Priority of the auth server policy
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Default to `ACTIVE`
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetTemplatesResult',
    'AwaitableGetTemplatesResult',
    'get_templates',
    'get_templates_output',
]

@pulumi.output_type
class GetTemplatesResult:
    """
    A collection of values returned by getTemplates.
    """
    def __init__(__self__, brand_id=None, email_templates=None, id=None):
        if brand_id and not isinstance(brand_id, str):
            raise TypeError("Expected argument 'brand_id' to be a str")
        pulumi.set(__self__, "brand_id", brand_id)
        if email_templates and not isinstance(email_templates, list):
            raise TypeError("Expected argument 'email_templates' to be a list")
        pulumi.set(__self__, "email_templates", email_templates)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> _builtins.str:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @_builtins.property
    @pulumi.getter(name="emailTemplates")
    def email_templates(self) -> Sequence['outputs.GetTemplatesEmailTemplateResult']:
        """
        List of `get_template` belonging to a brand in the organization
        """
        return pulumi.get(self, "email_templates")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetTemplatesResult(GetTemplatesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTemplatesResult(
            brand_id=self.brand_id,
            email_templates=self.email_templates,
            id=self.id)


def get_templates(brand_id: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTemplatesResult:
    """
    Get the email templates belonging to a brand in an Okta organization.


    :param _builtins.str brand_id: Brand ID
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getTemplates:getTemplates', __args__, opts=opts, typ=GetTemplatesResult).value

    return AwaitableGetTemplatesResult(
        brand_id=pulumi.get(__ret__, 'brand_id'),
        email_templates=pulumi.get(__ret__, 'email_templates'),
        id=pulumi.get(__ret__, 'id'))
def get_templates_output(brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTemplatesResult]:
    """
    Get the email templates belonging to a brand in an Okta organization.


    :param _builtins.str brand_id: Brand ID
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getTemplates:getTemplates', __args__, opts=opts, typ=GetTemplatesResult)
    return __ret__.apply(lambda __response__: GetTemplatesResult(
        brand_id=pulumi.get(__response__, 'brand_id'),
        email_templates=pulumi.get(__response__, 'email_templates'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetEmailSmtpServerResult',
    'AwaitableGetEmailSmtpServerResult',
    'get_email_smtp_server',
    'get_email_smtp_server_output',
]

@pulumi.output_type
class GetEmailSmtpServerResult:
    """
    A collection of values returned by getEmailSmtpServer.
    """
    def __init__(__self__, alias=None, enabled=None, host=None, id=None, port=None, username=None):
        if alias and not isinstance(alias, str):
            raise TypeError("Expected argument 'alias' to be a str")
        pulumi.set(__self__, "alias", alias)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if host and not isinstance(host, str):
            raise TypeError("Expected argument 'host' to be a str")
        pulumi.set(__self__, "host", host)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def alias(self) -> _builtins.str:
        """
        Human-readable name for SMTP server
        """
        return pulumi.get(self, "alias")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        If true, routes all email traffic through the SMTP server.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def host(self) -> _builtins.str:
        """
        Hostname or IP address of the SMTP server
        """
        return pulumi.get(self, "host")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of your SMTP server
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        The port number of the SMTP server
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def username(self) -> _builtins.str:
        """
        Username used to access the SMTP server
        """
        return pulumi.get(self, "username")


class AwaitableGetEmailSmtpServerResult(GetEmailSmtpServerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEmailSmtpServerResult(
            alias=self.alias,
            enabled=self.enabled,
            host=self.host,
            id=self.id,
            port=self.port,
            username=self.username)


def get_email_smtp_server(id: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEmailSmtpServerResult:
    """
    Get existing SMTP email server configuration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    smtp_server = okta.EmailSmtpServer("smtp_server",
        alias="CustomServer",
        host="192.168.160.1",
        port=8086,
        username="aUser",
        password="abcd")
    server_config = okta.get_email_smtp_server(id="id-of-your-smtp-server")
    ```


    :param _builtins.str id: ID of your SMTP server
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getEmailSmtpServer:getEmailSmtpServer', __args__, opts=opts, typ=GetEmailSmtpServerResult).value

    return AwaitableGetEmailSmtpServerResult(
        alias=pulumi.get(__ret__, 'alias'),
        enabled=pulumi.get(__ret__, 'enabled'),
        host=pulumi.get(__ret__, 'host'),
        id=pulumi.get(__ret__, 'id'),
        port=pulumi.get(__ret__, 'port'),
        username=pulumi.get(__ret__, 'username'))
def get_email_smtp_server_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEmailSmtpServerResult]:
    """
    Get existing SMTP email server configuration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    smtp_server = okta.EmailSmtpServer("smtp_server",
        alias="CustomServer",
        host="192.168.160.1",
        port=8086,
        username="aUser",
        password="abcd")
    server_config = okta.get_email_smtp_server(id="id-of-your-smtp-server")
    ```


    :param _builtins.str id: ID of your SMTP server
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getEmailSmtpServer:getEmailSmtpServer', __args__, opts=opts, typ=GetEmailSmtpServerResult)
    return __ret__.apply(lambda __response__: GetEmailSmtpServerResult(
        alias=pulumi.get(__response__, 'alias'),
        enabled=pulumi.get(__response__, 'enabled'),
        host=pulumi.get(__response__, 'host'),
        id=pulumi.get(__response__, 'id'),
        port=pulumi.get(__response__, 'port'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['BrandArgs', 'Brand']

@pulumi.input_type
class BrandArgs:
    def __init__(__self__, *,
                 agree_to_custom_privacy_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_privacy_policy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_app_instance_id: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_app_link_name: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_classic_application_uri: Optional[pulumi.Input[_builtins.str]] = None,
                 locale: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 remove_powered_by_okta: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a Brand resource.
        :param pulumi.Input[_builtins.bool] agree_to_custom_privacy_policy: Is a required input flag with when changing custom*privacy*url, shouldn't be considered as a readable property
        :param pulumi.Input[_builtins.str] brand_id: Brand ID - Note: Okta API for brands only reads and updates therefore the okta*brand resource needs to act as a quasi data source. Do this by setting brand*id. `DEPRECATED`: Okta has fully support brand creation, this attribute is a no op and will be removed
        :param pulumi.Input[_builtins.str] custom_privacy_policy_url: Custom privacy policy URL
        :param pulumi.Input[_builtins.str] default_app_app_instance_id: Default app app instance id
        :param pulumi.Input[_builtins.str] default_app_app_link_name: Default app app link name
        :param pulumi.Input[_builtins.str] default_app_classic_application_uri: Default app classic application uri
        :param pulumi.Input[_builtins.str] locale: The language specified as an IETF BCP 47 language tag
        :param pulumi.Input[_builtins.str] name: Name of the brand
        :param pulumi.Input[_builtins.bool] remove_powered_by_okta: Removes "Powered by Okta" from the Okta-hosted sign-in page and "© 2021 Okta, Inc." from the Okta End-User Dashboard
        """
        if agree_to_custom_privacy_policy is not None:
            pulumi.set(__self__, "agree_to_custom_privacy_policy", agree_to_custom_privacy_policy)
        if brand_id is not None:
            warnings.warn("""Okta has fully support brand creation, this attribute is a no op and will be removed""", DeprecationWarning)
            pulumi.log.warn("""brand_id is deprecated: Okta has fully support brand creation, this attribute is a no op and will be removed""")
        if brand_id is not None:
            pulumi.set(__self__, "brand_id", brand_id)
        if custom_privacy_policy_url is not None:
            pulumi.set(__self__, "custom_privacy_policy_url", custom_privacy_policy_url)
        if default_app_app_instance_id is not None:
            pulumi.set(__self__, "default_app_app_instance_id", default_app_app_instance_id)
        if default_app_app_link_name is not None:
            pulumi.set(__self__, "default_app_app_link_name", default_app_app_link_name)
        if default_app_classic_application_uri is not None:
            pulumi.set(__self__, "default_app_classic_application_uri", default_app_classic_application_uri)
        if locale is not None:
            pulumi.set(__self__, "locale", locale)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if remove_powered_by_okta is not None:
            pulumi.set(__self__, "remove_powered_by_okta", remove_powered_by_okta)

    @_builtins.property
    @pulumi.getter(name="agreeToCustomPrivacyPolicy")
    def agree_to_custom_privacy_policy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Is a required input flag with when changing custom*privacy*url, shouldn't be considered as a readable property
        """
        return pulumi.get(self, "agree_to_custom_privacy_policy")

    @agree_to_custom_privacy_policy.setter
    def agree_to_custom_privacy_policy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "agree_to_custom_privacy_policy", value)

    @_builtins.property
    @pulumi.getter(name="brandId")
    @_utilities.deprecated("""Okta has fully support brand creation, this attribute is a no op and will be removed""")
    def brand_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Brand ID - Note: Okta API for brands only reads and updates therefore the okta*brand resource needs to act as a quasi data source. Do this by setting brand*id. `DEPRECATED`: Okta has fully support brand creation, this attribute is a no op and will be removed
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "brand_id", value)

    @_builtins.property
    @pulumi.getter(name="customPrivacyPolicyUrl")
    def custom_privacy_policy_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom privacy policy URL
        """
        return pulumi.get(self, "custom_privacy_policy_url")

    @custom_privacy_policy_url.setter
    def custom_privacy_policy_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_privacy_policy_url", value)

    @_builtins.property
    @pulumi.getter(name="defaultAppAppInstanceId")
    def default_app_app_instance_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default app app instance id
        """
        return pulumi.get(self, "default_app_app_instance_id")

    @default_app_app_instance_id.setter
    def default_app_app_instance_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_app_app_instance_id", value)

    @_builtins.property
    @pulumi.getter(name="defaultAppAppLinkName")
    def default_app_app_link_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default app app link name
        """
        return pulumi.get(self, "default_app_app_link_name")

    @default_app_app_link_name.setter
    def default_app_app_link_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_app_app_link_name", value)

    @_builtins.property
    @pulumi.getter(name="defaultAppClassicApplicationUri")
    def default_app_classic_application_uri(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default app classic application uri
        """
        return pulumi.get(self, "default_app_classic_application_uri")

    @default_app_classic_application_uri.setter
    def default_app_classic_application_uri(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_app_classic_application_uri", value)

    @_builtins.property
    @pulumi.getter
    def locale(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The language specified as an IETF BCP 47 language tag
        """
        return pulumi.get(self, "locale")

    @locale.setter
    def locale(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "locale", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the brand
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="removePoweredByOkta")
    def remove_powered_by_okta(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Removes "Powered by Okta" from the Okta-hosted sign-in page and "© 2021 Okta, Inc." from the Okta End-User Dashboard
        """
        return pulumi.get(self, "remove_powered_by_okta")

    @remove_powered_by_okta.setter
    def remove_powered_by_okta(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "remove_powered_by_okta", value)


@pulumi.input_type
class _BrandState:
    def __init__(__self__, *,
                 agree_to_custom_privacy_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_privacy_policy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_app_instance_id: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_app_link_name: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_classic_application_uri: Optional[pulumi.Input[_builtins.str]] = None,
                 email_domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 links: Optional[pulumi.Input[_builtins.str]] = None,
                 locale: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 remove_powered_by_okta: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Brand resources.
        :param pulumi.Input[_builtins.bool] agree_to_custom_privacy_policy: Is a required input flag with when changing custom*privacy*url, shouldn't be considered as a readable property
        :param pulumi.Input[_builtins.str] brand_id: Brand ID - Note: Okta API for brands only reads and updates therefore the okta*brand resource needs to act as a quasi data source. Do this by setting brand*id. `DEPRECATED`: Okta has fully support brand creation, this attribute is a no op and will be removed
        :param pulumi.Input[_builtins.str] custom_privacy_policy_url: Custom privacy policy URL
        :param pulumi.Input[_builtins.str] default_app_app_instance_id: Default app app instance id
        :param pulumi.Input[_builtins.str] default_app_app_link_name: Default app app link name
        :param pulumi.Input[_builtins.str] default_app_classic_application_uri: Default app classic application uri
        :param pulumi.Input[_builtins.str] email_domain_id: Email Domain ID tied to this brand
        :param pulumi.Input[_builtins.bool] is_default: Is this the default brand
        :param pulumi.Input[_builtins.str] links: Link relations for this object - JSON HAL - Discoverable resources related to the brand
        :param pulumi.Input[_builtins.str] locale: The language specified as an IETF BCP 47 language tag
        :param pulumi.Input[_builtins.str] name: Name of the brand
        :param pulumi.Input[_builtins.bool] remove_powered_by_okta: Removes "Powered by Okta" from the Okta-hosted sign-in page and "© 2021 Okta, Inc." from the Okta End-User Dashboard
        """
        if agree_to_custom_privacy_policy is not None:
            pulumi.set(__self__, "agree_to_custom_privacy_policy", agree_to_custom_privacy_policy)
        if brand_id is not None:
            warnings.warn("""Okta has fully support brand creation, this attribute is a no op and will be removed""", DeprecationWarning)
            pulumi.log.warn("""brand_id is deprecated: Okta has fully support brand creation, this attribute is a no op and will be removed""")
        if brand_id is not None:
            pulumi.set(__self__, "brand_id", brand_id)
        if custom_privacy_policy_url is not None:
            pulumi.set(__self__, "custom_privacy_policy_url", custom_privacy_policy_url)
        if default_app_app_instance_id is not None:
            pulumi.set(__self__, "default_app_app_instance_id", default_app_app_instance_id)
        if default_app_app_link_name is not None:
            pulumi.set(__self__, "default_app_app_link_name", default_app_app_link_name)
        if default_app_classic_application_uri is not None:
            pulumi.set(__self__, "default_app_classic_application_uri", default_app_classic_application_uri)
        if email_domain_id is not None:
            pulumi.set(__self__, "email_domain_id", email_domain_id)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if locale is not None:
            pulumi.set(__self__, "locale", locale)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if remove_powered_by_okta is not None:
            pulumi.set(__self__, "remove_powered_by_okta", remove_powered_by_okta)

    @_builtins.property
    @pulumi.getter(name="agreeToCustomPrivacyPolicy")
    def agree_to_custom_privacy_policy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Is a required input flag with when changing custom*privacy*url, shouldn't be considered as a readable property
        """
        return pulumi.get(self, "agree_to_custom_privacy_policy")

    @agree_to_custom_privacy_policy.setter
    def agree_to_custom_privacy_policy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "agree_to_custom_privacy_policy", value)

    @_builtins.property
    @pulumi.getter(name="brandId")
    @_utilities.deprecated("""Okta has fully support brand creation, this attribute is a no op and will be removed""")
    def brand_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Brand ID - Note: Okta API for brands only reads and updates therefore the okta*brand resource needs to act as a quasi data source. Do this by setting brand*id. `DEPRECATED`: Okta has fully support brand creation, this attribute is a no op and will be removed
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "brand_id", value)

    @_builtins.property
    @pulumi.getter(name="customPrivacyPolicyUrl")
    def custom_privacy_policy_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom privacy policy URL
        """
        return pulumi.get(self, "custom_privacy_policy_url")

    @custom_privacy_policy_url.setter
    def custom_privacy_policy_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_privacy_policy_url", value)

    @_builtins.property
    @pulumi.getter(name="defaultAppAppInstanceId")
    def default_app_app_instance_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default app app instance id
        """
        return pulumi.get(self, "default_app_app_instance_id")

    @default_app_app_instance_id.setter
    def default_app_app_instance_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_app_app_instance_id", value)

    @_builtins.property
    @pulumi.getter(name="defaultAppAppLinkName")
    def default_app_app_link_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default app app link name
        """
        return pulumi.get(self, "default_app_app_link_name")

    @default_app_app_link_name.setter
    def default_app_app_link_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_app_app_link_name", value)

    @_builtins.property
    @pulumi.getter(name="defaultAppClassicApplicationUri")
    def default_app_classic_application_uri(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default app classic application uri
        """
        return pulumi.get(self, "default_app_classic_application_uri")

    @default_app_classic_application_uri.setter
    def default_app_classic_application_uri(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_app_classic_application_uri", value)

    @_builtins.property
    @pulumi.getter(name="emailDomainId")
    def email_domain_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Email Domain ID tied to this brand
        """
        return pulumi.get(self, "email_domain_id")

    @email_domain_id.setter
    def email_domain_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email_domain_id", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Is this the default brand
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Link relations for this object - JSON HAL - Discoverable resources related to the brand
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "links", value)

    @_builtins.property
    @pulumi.getter
    def locale(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The language specified as an IETF BCP 47 language tag
        """
        return pulumi.get(self, "locale")

    @locale.setter
    def locale(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "locale", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the brand
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="removePoweredByOkta")
    def remove_powered_by_okta(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Removes "Powered by Okta" from the Okta-hosted sign-in page and "© 2021 Okta, Inc." from the Okta End-User Dashboard
        """
        return pulumi.get(self, "remove_powered_by_okta")

    @remove_powered_by_okta.setter
    def remove_powered_by_okta(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "remove_powered_by_okta", value)


@pulumi.type_token("okta:index/brand:Brand")
class Brand(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agree_to_custom_privacy_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_privacy_policy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_app_instance_id: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_app_link_name: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_classic_application_uri: Optional[pulumi.Input[_builtins.str]] = None,
                 locale: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 remove_powered_by_okta: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Brand("example", name="example")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/brand:Brand example <brand_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] agree_to_custom_privacy_policy: Is a required input flag with when changing custom*privacy*url, shouldn't be considered as a readable property
        :param pulumi.Input[_builtins.str] brand_id: Brand ID - Note: Okta API for brands only reads and updates therefore the okta*brand resource needs to act as a quasi data source. Do this by setting brand*id. `DEPRECATED`: Okta has fully support brand creation, this attribute is a no op and will be removed
        :param pulumi.Input[_builtins.str] custom_privacy_policy_url: Custom privacy policy URL
        :param pulumi.Input[_builtins.str] default_app_app_instance_id: Default app app instance id
        :param pulumi.Input[_builtins.str] default_app_app_link_name: Default app app link name
        :param pulumi.Input[_builtins.str] default_app_classic_application_uri: Default app classic application uri
        :param pulumi.Input[_builtins.str] locale: The language specified as an IETF BCP 47 language tag
        :param pulumi.Input[_builtins.str] name: Name of the brand
        :param pulumi.Input[_builtins.bool] remove_powered_by_okta: Removes "Powered by Okta" from the Okta-hosted sign-in page and "© 2021 Okta, Inc." from the Okta End-User Dashboard
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[BrandArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Brand("example", name="example")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/brand:Brand example <brand_id>
        ```

        :param str resource_name: The name of the resource.
        :param BrandArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BrandArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agree_to_custom_privacy_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_privacy_policy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_app_instance_id: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_app_link_name: Optional[pulumi.Input[_builtins.str]] = None,
                 default_app_classic_application_uri: Optional[pulumi.Input[_builtins.str]] = None,
                 locale: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 remove_powered_by_okta: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BrandArgs.__new__(BrandArgs)

            __props__.__dict__["agree_to_custom_privacy_policy"] = agree_to_custom_privacy_policy
            __props__.__dict__["brand_id"] = brand_id
            __props__.__dict__["custom_privacy_policy_url"] = custom_privacy_policy_url
            __props__.__dict__["default_app_app_instance_id"] = default_app_app_instance_id
            __props__.__dict__["default_app_app_link_name"] = default_app_app_link_name
            __props__.__dict__["default_app_classic_application_uri"] = default_app_classic_application_uri
            __props__.__dict__["locale"] = locale
            __props__.__dict__["name"] = name
            __props__.__dict__["remove_powered_by_okta"] = remove_powered_by_okta
            __props__.__dict__["email_domain_id"] = None
            __props__.__dict__["is_default"] = None
            __props__.__dict__["links"] = None
        super(Brand, __self__).__init__(
            'okta:index/brand:Brand',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            agree_to_custom_privacy_policy: Optional[pulumi.Input[_builtins.bool]] = None,
            brand_id: Optional[pulumi.Input[_builtins.str]] = None,
            custom_privacy_policy_url: Optional[pulumi.Input[_builtins.str]] = None,
            default_app_app_instance_id: Optional[pulumi.Input[_builtins.str]] = None,
            default_app_app_link_name: Optional[pulumi.Input[_builtins.str]] = None,
            default_app_classic_application_uri: Optional[pulumi.Input[_builtins.str]] = None,
            email_domain_id: Optional[pulumi.Input[_builtins.str]] = None,
            is_default: Optional[pulumi.Input[_builtins.bool]] = None,
            links: Optional[pulumi.Input[_builtins.str]] = None,
            locale: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            remove_powered_by_okta: Optional[pulumi.Input[_builtins.bool]] = None) -> 'Brand':
        """
        Get an existing Brand resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] agree_to_custom_privacy_policy: Is a required input flag with when changing custom*privacy*url, shouldn't be considered as a readable property
        :param pulumi.Input[_builtins.str] brand_id: Brand ID - Note: Okta API for brands only reads and updates therefore the okta*brand resource needs to act as a quasi data source. Do this by setting brand*id. `DEPRECATED`: Okta has fully support brand creation, this attribute is a no op and will be removed
        :param pulumi.Input[_builtins.str] custom_privacy_policy_url: Custom privacy policy URL
        :param pulumi.Input[_builtins.str] default_app_app_instance_id: Default app app instance id
        :param pulumi.Input[_builtins.str] default_app_app_link_name: Default app app link name
        :param pulumi.Input[_builtins.str] default_app_classic_application_uri: Default app classic application uri
        :param pulumi.Input[_builtins.str] email_domain_id: Email Domain ID tied to this brand
        :param pulumi.Input[_builtins.bool] is_default: Is this the default brand
        :param pulumi.Input[_builtins.str] links: Link relations for this object - JSON HAL - Discoverable resources related to the brand
        :param pulumi.Input[_builtins.str] locale: The language specified as an IETF BCP 47 language tag
        :param pulumi.Input[_builtins.str] name: Name of the brand
        :param pulumi.Input[_builtins.bool] remove_powered_by_okta: Removes "Powered by Okta" from the Okta-hosted sign-in page and "© 2021 Okta, Inc." from the Okta End-User Dashboard
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BrandState.__new__(_BrandState)

        __props__.__dict__["agree_to_custom_privacy_policy"] = agree_to_custom_privacy_policy
        __props__.__dict__["brand_id"] = brand_id
        __props__.__dict__["custom_privacy_policy_url"] = custom_privacy_policy_url
        __props__.__dict__["default_app_app_instance_id"] = default_app_app_instance_id
        __props__.__dict__["default_app_app_link_name"] = default_app_app_link_name
        __props__.__dict__["default_app_classic_application_uri"] = default_app_classic_application_uri
        __props__.__dict__["email_domain_id"] = email_domain_id
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["links"] = links
        __props__.__dict__["locale"] = locale
        __props__.__dict__["name"] = name
        __props__.__dict__["remove_powered_by_okta"] = remove_powered_by_okta
        return Brand(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="agreeToCustomPrivacyPolicy")
    def agree_to_custom_privacy_policy(self) -> pulumi.Output[_builtins.bool]:
        """
        Is a required input flag with when changing custom*privacy*url, shouldn't be considered as a readable property
        """
        return pulumi.get(self, "agree_to_custom_privacy_policy")

    @_builtins.property
    @pulumi.getter(name="brandId")
    @_utilities.deprecated("""Okta has fully support brand creation, this attribute is a no op and will be removed""")
    def brand_id(self) -> pulumi.Output[_builtins.str]:
        """
        Brand ID - Note: Okta API for brands only reads and updates therefore the okta*brand resource needs to act as a quasi data source. Do this by setting brand*id. `DEPRECATED`: Okta has fully support brand creation, this attribute is a no op and will be removed
        """
        return pulumi.get(self, "brand_id")

    @_builtins.property
    @pulumi.getter(name="customPrivacyPolicyUrl")
    def custom_privacy_policy_url(self) -> pulumi.Output[_builtins.str]:
        """
        Custom privacy policy URL
        """
        return pulumi.get(self, "custom_privacy_policy_url")

    @_builtins.property
    @pulumi.getter(name="defaultAppAppInstanceId")
    def default_app_app_instance_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Default app app instance id
        """
        return pulumi.get(self, "default_app_app_instance_id")

    @_builtins.property
    @pulumi.getter(name="defaultAppAppLinkName")
    def default_app_app_link_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Default app app link name
        """
        return pulumi.get(self, "default_app_app_link_name")

    @_builtins.property
    @pulumi.getter(name="defaultAppClassicApplicationUri")
    def default_app_classic_application_uri(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Default app classic application uri
        """
        return pulumi.get(self, "default_app_classic_application_uri")

    @_builtins.property
    @pulumi.getter(name="emailDomainId")
    def email_domain_id(self) -> pulumi.Output[_builtins.str]:
        """
        Email Domain ID tied to this brand
        """
        return pulumi.get(self, "email_domain_id")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[_builtins.bool]:
        """
        Is this the default brand
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter
    def links(self) -> pulumi.Output[_builtins.str]:
        """
        Link relations for this object - JSON HAL - Discoverable resources related to the brand
        """
        return pulumi.get(self, "links")

    @_builtins.property
    @pulumi.getter
    def locale(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The language specified as an IETF BCP 47 language tag
        """
        return pulumi.get(self, "locale")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the brand
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="removePoweredByOkta")
    def remove_powered_by_okta(self) -> pulumi.Output[_builtins.bool]:
        """
        Removes "Powered by Okta" from the Okta-hosted sign-in page and "© 2021 Okta, Inc." from the Okta End-User Dashboard
        """
        return pulumi.get(self, "remove_powered_by_okta")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDeviceAssurancePolicyResult',
    'AwaitableGetDeviceAssurancePolicyResult',
    'get_device_assurance_policy',
    'get_device_assurance_policy_output',
]

@pulumi.output_type
class GetDeviceAssurancePolicyResult:
    """
    A collection of values returned by getDeviceAssurancePolicy.
    """
    def __init__(__self__, disk_encryption_type=None, id=None, jailbreak=None, name=None, os_version=None, os_version_constraints=None, platform=None, screenlock_type=None, secure_hardware_present=None, third_party_signal_provider=None):
        if disk_encryption_type and not isinstance(disk_encryption_type, dict):
            raise TypeError("Expected argument 'disk_encryption_type' to be a dict")
        pulumi.set(__self__, "disk_encryption_type", disk_encryption_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if jailbreak and not isinstance(jailbreak, bool):
            raise TypeError("Expected argument 'jailbreak' to be a bool")
        pulumi.set(__self__, "jailbreak", jailbreak)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if os_version and not isinstance(os_version, dict):
            raise TypeError("Expected argument 'os_version' to be a dict")
        pulumi.set(__self__, "os_version", os_version)
        if os_version_constraints and not isinstance(os_version_constraints, list):
            raise TypeError("Expected argument 'os_version_constraints' to be a list")
        pulumi.set(__self__, "os_version_constraints", os_version_constraints)
        if platform and not isinstance(platform, str):
            raise TypeError("Expected argument 'platform' to be a str")
        pulumi.set(__self__, "platform", platform)
        if screenlock_type and not isinstance(screenlock_type, dict):
            raise TypeError("Expected argument 'screenlock_type' to be a dict")
        pulumi.set(__self__, "screenlock_type", screenlock_type)
        if secure_hardware_present and not isinstance(secure_hardware_present, bool):
            raise TypeError("Expected argument 'secure_hardware_present' to be a bool")
        pulumi.set(__self__, "secure_hardware_present", secure_hardware_present)
        if third_party_signal_provider and not isinstance(third_party_signal_provider, dict):
            raise TypeError("Expected argument 'third_party_signal_provider' to be a dict")
        pulumi.set(__self__, "third_party_signal_provider", third_party_signal_provider)

    @_builtins.property
    @pulumi.getter(name="diskEncryptionType")
    def disk_encryption_type(self) -> 'outputs.GetDeviceAssurancePolicyDiskEncryptionTypeResult':
        """
        List of disk encryption type, can be `FULL`, `USER`
        """
        return pulumi.get(self, "disk_encryption_type")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        ID of the user type to retrieve, conflicts with `name`.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def jailbreak(self) -> _builtins.bool:
        """
        Is the device jailbroken in the device assurance policy.
        """
        return pulumi.get(self, "jailbreak")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of user type to retrieve, conflicts with `id`.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="osVersion")
    def os_version(self) -> 'outputs.GetDeviceAssurancePolicyOsVersionResult':
        """
        Minimum os version of the device in the device assurance policy.
        """
        return pulumi.get(self, "os_version")

    @_builtins.property
    @pulumi.getter(name="osVersionConstraints")
    def os_version_constraints(self) -> Sequence['outputs.GetDeviceAssurancePolicyOsVersionConstraintResult']:
        """
        The list of os version constraints.
        """
        return pulumi.get(self, "os_version_constraints")

    @_builtins.property
    @pulumi.getter
    def platform(self) -> _builtins.str:
        """
        Policy device assurance platform
        """
        return pulumi.get(self, "platform")

    @_builtins.property
    @pulumi.getter(name="screenlockType")
    def screenlock_type(self) -> 'outputs.GetDeviceAssurancePolicyScreenlockTypeResult':
        """
        List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        """
        return pulumi.get(self, "screenlock_type")

    @_builtins.property
    @pulumi.getter(name="secureHardwarePresent")
    def secure_hardware_present(self) -> Optional[_builtins.bool]:
        """
        Indicates if the device contains a secure hardware functionality
        """
        return pulumi.get(self, "secure_hardware_present")

    @_builtins.property
    @pulumi.getter(name="thirdPartySignalProvider")
    def third_party_signal_provider(self) -> Optional['outputs.GetDeviceAssurancePolicyThirdPartySignalProviderResult']:
        """
        Indicates if the device contains a secure hardware functionality
        """
        return pulumi.get(self, "third_party_signal_provider")


class AwaitableGetDeviceAssurancePolicyResult(GetDeviceAssurancePolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDeviceAssurancePolicyResult(
            disk_encryption_type=self.disk_encryption_type,
            id=self.id,
            jailbreak=self.jailbreak,
            name=self.name,
            os_version=self.os_version,
            os_version_constraints=self.os_version_constraints,
            platform=self.platform,
            screenlock_type=self.screenlock_type,
            secure_hardware_present=self.secure_hardware_present,
            third_party_signal_provider=self.third_party_signal_provider)


def get_device_assurance_policy(id: Optional[_builtins.str] = None,
                                name: Optional[_builtins.str] = None,
                                secure_hardware_present: Optional[_builtins.bool] = None,
                                third_party_signal_provider: Optional[Union['GetDeviceAssurancePolicyThirdPartySignalProviderArgs', 'GetDeviceAssurancePolicyThirdPartySignalProviderArgsDict']] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDeviceAssurancePolicyResult:
    """
    Get a policy assurance from Okta.


    :param _builtins.str id: ID of the user type to retrieve, conflicts with `name`.
    :param _builtins.str name: Name of user type to retrieve, conflicts with `id`.
    :param _builtins.bool secure_hardware_present: Indicates if the device contains a secure hardware functionality
    :param Union['GetDeviceAssurancePolicyThirdPartySignalProviderArgs', 'GetDeviceAssurancePolicyThirdPartySignalProviderArgsDict'] third_party_signal_provider: Indicates if the device contains a secure hardware functionality
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['secureHardwarePresent'] = secure_hardware_present
    __args__['thirdPartySignalProvider'] = third_party_signal_provider
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getDeviceAssurancePolicy:getDeviceAssurancePolicy', __args__, opts=opts, typ=GetDeviceAssurancePolicyResult).value

    return AwaitableGetDeviceAssurancePolicyResult(
        disk_encryption_type=pulumi.get(__ret__, 'disk_encryption_type'),
        id=pulumi.get(__ret__, 'id'),
        jailbreak=pulumi.get(__ret__, 'jailbreak'),
        name=pulumi.get(__ret__, 'name'),
        os_version=pulumi.get(__ret__, 'os_version'),
        os_version_constraints=pulumi.get(__ret__, 'os_version_constraints'),
        platform=pulumi.get(__ret__, 'platform'),
        screenlock_type=pulumi.get(__ret__, 'screenlock_type'),
        secure_hardware_present=pulumi.get(__ret__, 'secure_hardware_present'),
        third_party_signal_provider=pulumi.get(__ret__, 'third_party_signal_provider'))
def get_device_assurance_policy_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                       name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                       secure_hardware_present: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                       third_party_signal_provider: Optional[pulumi.Input[Optional[Union['GetDeviceAssurancePolicyThirdPartySignalProviderArgs', 'GetDeviceAssurancePolicyThirdPartySignalProviderArgsDict']]]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDeviceAssurancePolicyResult]:
    """
    Get a policy assurance from Okta.


    :param _builtins.str id: ID of the user type to retrieve, conflicts with `name`.
    :param _builtins.str name: Name of user type to retrieve, conflicts with `id`.
    :param _builtins.bool secure_hardware_present: Indicates if the device contains a secure hardware functionality
    :param Union['GetDeviceAssurancePolicyThirdPartySignalProviderArgs', 'GetDeviceAssurancePolicyThirdPartySignalProviderArgsDict'] third_party_signal_provider: Indicates if the device contains a secure hardware functionality
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['secureHardwarePresent'] = secure_hardware_present
    __args__['thirdPartySignalProvider'] = third_party_signal_provider
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getDeviceAssurancePolicy:getDeviceAssurancePolicy', __args__, opts=opts, typ=GetDeviceAssurancePolicyResult)
    return __ret__.apply(lambda __response__: GetDeviceAssurancePolicyResult(
        disk_encryption_type=pulumi.get(__response__, 'disk_encryption_type'),
        id=pulumi.get(__response__, 'id'),
        jailbreak=pulumi.get(__response__, 'jailbreak'),
        name=pulumi.get(__response__, 'name'),
        os_version=pulumi.get(__response__, 'os_version'),
        os_version_constraints=pulumi.get(__response__, 'os_version_constraints'),
        platform=pulumi.get(__response__, 'platform'),
        screenlock_type=pulumi.get(__response__, 'screenlock_type'),
        secure_hardware_present=pulumi.get(__response__, 'secure_hardware_present'),
        third_party_signal_provider=pulumi.get(__response__, 'third_party_signal_provider')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['EventHookVerificationArgs', 'EventHookVerification']

@pulumi.input_type
class EventHookVerificationArgs:
    def __init__(__self__, *,
                 event_hook_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a EventHookVerification resource.
        :param pulumi.Input[_builtins.str] event_hook_id: Event hook ID
        """
        pulumi.set(__self__, "event_hook_id", event_hook_id)

    @_builtins.property
    @pulumi.getter(name="eventHookId")
    def event_hook_id(self) -> pulumi.Input[_builtins.str]:
        """
        Event hook ID
        """
        return pulumi.get(self, "event_hook_id")

    @event_hook_id.setter
    def event_hook_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "event_hook_id", value)


@pulumi.input_type
class _EventHookVerificationState:
    def __init__(__self__, *,
                 event_hook_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EventHookVerification resources.
        :param pulumi.Input[_builtins.str] event_hook_id: Event hook ID
        """
        if event_hook_id is not None:
            pulumi.set(__self__, "event_hook_id", event_hook_id)

    @_builtins.property
    @pulumi.getter(name="eventHookId")
    def event_hook_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Event hook ID
        """
        return pulumi.get(self, "event_hook_id")

    @event_hook_id.setter
    def event_hook_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "event_hook_id", value)


@pulumi.type_token("okta:index/eventHookVerification:EventHookVerification")
class EventHookVerification(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 event_hook_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Verifies the Event Hook. The resource won't be created unless the URI provided in the event hook returns a valid JSON object with verification. See [Event Hooks](https://developer.okta.com/docs/concepts/event-hooks/#one-time-verification-request) documentation for details.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.EventHook("example",
            name="example",
            events=[
                "user.lifecycle.create",
                "user.lifecycle.delete.initiated",
            ],
            channel={
                "type": "HTTP",
                "version": "1.0.0",
                "uri": "https://example.com/test",
            },
            auth={
                "type": "HEADER",
                "key": "Authorization",
                "value": "123",
            })
        example_event_hook_verification = okta.EventHookVerification("example", event_hook_id=example.id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] event_hook_id: Event hook ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EventHookVerificationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Verifies the Event Hook. The resource won't be created unless the URI provided in the event hook returns a valid JSON object with verification. See [Event Hooks](https://developer.okta.com/docs/concepts/event-hooks/#one-time-verification-request) documentation for details.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.EventHook("example",
            name="example",
            events=[
                "user.lifecycle.create",
                "user.lifecycle.delete.initiated",
            ],
            channel={
                "type": "HTTP",
                "version": "1.0.0",
                "uri": "https://example.com/test",
            },
            auth={
                "type": "HEADER",
                "key": "Authorization",
                "value": "123",
            })
        example_event_hook_verification = okta.EventHookVerification("example", event_hook_id=example.id)
        ```

        :param str resource_name: The name of the resource.
        :param EventHookVerificationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EventHookVerificationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 event_hook_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EventHookVerificationArgs.__new__(EventHookVerificationArgs)

            if event_hook_id is None and not opts.urn:
                raise TypeError("Missing required property 'event_hook_id'")
            __props__.__dict__["event_hook_id"] = event_hook_id
        super(EventHookVerification, __self__).__init__(
            'okta:index/eventHookVerification:EventHookVerification',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            event_hook_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'EventHookVerification':
        """
        Get an existing EventHookVerification resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] event_hook_id: Event hook ID
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EventHookVerificationState.__new__(_EventHookVerificationState)

        __props__.__dict__["event_hook_id"] = event_hook_id
        return EventHookVerification(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="eventHookId")
    def event_hook_id(self) -> pulumi.Output[_builtins.str]:
        """
        Event hook ID
        """
        return pulumi.get(self, "event_hook_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RuleArgs', 'Rule']

@pulumi.input_type
class RuleArgs:
    def __init__(__self__, *,
                 expression_value: pulumi.Input[_builtins.str],
                 group_assignments: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 expression_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 remove_assigned_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 users_excludeds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Rule resource.
        :param pulumi.Input[_builtins.str] expression_value: The expression value.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] group_assignments: The list of group ids to assign the users to.
        :param pulumi.Input[_builtins.str] expression_type: The expression type to use to invoke the rule. The default is `urn:okta:expression:1.0`.
        :param pulumi.Input[_builtins.str] name: The name of the Group Rule (min character 1; max characters 50).
        :param pulumi.Input[_builtins.bool] remove_assigned_users: Remove users added by this rule from the assigned group after deleting this resource. Default is `false`
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users_excludeds: The list of user IDs that would be excluded when rules are processed
        """
        pulumi.set(__self__, "expression_value", expression_value)
        pulumi.set(__self__, "group_assignments", group_assignments)
        if expression_type is not None:
            pulumi.set(__self__, "expression_type", expression_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if remove_assigned_users is not None:
            pulumi.set(__self__, "remove_assigned_users", remove_assigned_users)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if users_excludeds is not None:
            pulumi.set(__self__, "users_excludeds", users_excludeds)

    @_builtins.property
    @pulumi.getter(name="expressionValue")
    def expression_value(self) -> pulumi.Input[_builtins.str]:
        """
        The expression value.
        """
        return pulumi.get(self, "expression_value")

    @expression_value.setter
    def expression_value(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "expression_value", value)

    @_builtins.property
    @pulumi.getter(name="groupAssignments")
    def group_assignments(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        The list of group ids to assign the users to.
        """
        return pulumi.get(self, "group_assignments")

    @group_assignments.setter
    def group_assignments(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "group_assignments", value)

    @_builtins.property
    @pulumi.getter(name="expressionType")
    def expression_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The expression type to use to invoke the rule. The default is `urn:okta:expression:1.0`.
        """
        return pulumi.get(self, "expression_type")

    @expression_type.setter
    def expression_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expression_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Group Rule (min character 1; max characters 50).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="removeAssignedUsers")
    def remove_assigned_users(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Remove users added by this rule from the assigned group after deleting this resource. Default is `false`
        """
        return pulumi.get(self, "remove_assigned_users")

    @remove_assigned_users.setter
    def remove_assigned_users(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "remove_assigned_users", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default to `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="usersExcludeds")
    def users_excludeds(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of user IDs that would be excluded when rules are processed
        """
        return pulumi.get(self, "users_excludeds")

    @users_excludeds.setter
    def users_excludeds(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "users_excludeds", value)


@pulumi.input_type
class _RuleState:
    def __init__(__self__, *,
                 expression_type: Optional[pulumi.Input[_builtins.str]] = None,
                 expression_value: Optional[pulumi.Input[_builtins.str]] = None,
                 group_assignments: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 remove_assigned_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 users_excludeds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Rule resources.
        :param pulumi.Input[_builtins.str] expression_type: The expression type to use to invoke the rule. The default is `urn:okta:expression:1.0`.
        :param pulumi.Input[_builtins.str] expression_value: The expression value.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] group_assignments: The list of group ids to assign the users to.
        :param pulumi.Input[_builtins.str] name: The name of the Group Rule (min character 1; max characters 50).
        :param pulumi.Input[_builtins.bool] remove_assigned_users: Remove users added by this rule from the assigned group after deleting this resource. Default is `false`
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users_excludeds: The list of user IDs that would be excluded when rules are processed
        """
        if expression_type is not None:
            pulumi.set(__self__, "expression_type", expression_type)
        if expression_value is not None:
            pulumi.set(__self__, "expression_value", expression_value)
        if group_assignments is not None:
            pulumi.set(__self__, "group_assignments", group_assignments)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if remove_assigned_users is not None:
            pulumi.set(__self__, "remove_assigned_users", remove_assigned_users)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if users_excludeds is not None:
            pulumi.set(__self__, "users_excludeds", users_excludeds)

    @_builtins.property
    @pulumi.getter(name="expressionType")
    def expression_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The expression type to use to invoke the rule. The default is `urn:okta:expression:1.0`.
        """
        return pulumi.get(self, "expression_type")

    @expression_type.setter
    def expression_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expression_type", value)

    @_builtins.property
    @pulumi.getter(name="expressionValue")
    def expression_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The expression value.
        """
        return pulumi.get(self, "expression_value")

    @expression_value.setter
    def expression_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expression_value", value)

    @_builtins.property
    @pulumi.getter(name="groupAssignments")
    def group_assignments(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of group ids to assign the users to.
        """
        return pulumi.get(self, "group_assignments")

    @group_assignments.setter
    def group_assignments(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "group_assignments", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Group Rule (min character 1; max characters 50).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="removeAssignedUsers")
    def remove_assigned_users(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Remove users added by this rule from the assigned group after deleting this resource. Default is `false`
        """
        return pulumi.get(self, "remove_assigned_users")

    @remove_assigned_users.setter
    def remove_assigned_users(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "remove_assigned_users", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default to `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="usersExcludeds")
    def users_excludeds(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of user IDs that would be excluded when rules are processed
        """
        return pulumi.get(self, "users_excludeds")

    @users_excludeds.setter
    def users_excludeds(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "users_excludeds", value)


@pulumi.type_token("okta:group/rule:Rule")
class Rule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expression_type: Optional[pulumi.Input[_builtins.str]] = None,
                 expression_value: Optional[pulumi.Input[_builtins.str]] = None,
                 group_assignments: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 remove_assigned_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 users_excludeds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.group.Rule("example",
            name="example",
            status="ACTIVE",
            group_assignments=["<group id>"],
            expression_type="urn:okta:expression:1.0",
            expression_value="String.startsWith(user.firstName,\\"andy\\")")
        ```

        ## Import

        ```sh
        $ pulumi import okta:group/rule:Rule example <group_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] expression_type: The expression type to use to invoke the rule. The default is `urn:okta:expression:1.0`.
        :param pulumi.Input[_builtins.str] expression_value: The expression value.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] group_assignments: The list of group ids to assign the users to.
        :param pulumi.Input[_builtins.str] name: The name of the Group Rule (min character 1; max characters 50).
        :param pulumi.Input[_builtins.bool] remove_assigned_users: Remove users added by this rule from the assigned group after deleting this resource. Default is `false`
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users_excludeds: The list of user IDs that would be excluded when rules are processed
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.group.Rule("example",
            name="example",
            status="ACTIVE",
            group_assignments=["<group id>"],
            expression_type="urn:okta:expression:1.0",
            expression_value="String.startsWith(user.firstName,\\"andy\\")")
        ```

        ## Import

        ```sh
        $ pulumi import okta:group/rule:Rule example <group_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param RuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expression_type: Optional[pulumi.Input[_builtins.str]] = None,
                 expression_value: Optional[pulumi.Input[_builtins.str]] = None,
                 group_assignments: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 remove_assigned_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 users_excludeds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleArgs.__new__(RuleArgs)

            __props__.__dict__["expression_type"] = expression_type
            if expression_value is None and not opts.urn:
                raise TypeError("Missing required property 'expression_value'")
            __props__.__dict__["expression_value"] = expression_value
            if group_assignments is None and not opts.urn:
                raise TypeError("Missing required property 'group_assignments'")
            __props__.__dict__["group_assignments"] = group_assignments
            __props__.__dict__["name"] = name
            __props__.__dict__["remove_assigned_users"] = remove_assigned_users
            __props__.__dict__["status"] = status
            __props__.__dict__["users_excludeds"] = users_excludeds
        super(Rule, __self__).__init__(
            'okta:group/rule:Rule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            expression_type: Optional[pulumi.Input[_builtins.str]] = None,
            expression_value: Optional[pulumi.Input[_builtins.str]] = None,
            group_assignments: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            remove_assigned_users: Optional[pulumi.Input[_builtins.bool]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            users_excludeds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'Rule':
        """
        Get an existing Rule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] expression_type: The expression type to use to invoke the rule. The default is `urn:okta:expression:1.0`.
        :param pulumi.Input[_builtins.str] expression_value: The expression value.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] group_assignments: The list of group ids to assign the users to.
        :param pulumi.Input[_builtins.str] name: The name of the Group Rule (min character 1; max characters 50).
        :param pulumi.Input[_builtins.bool] remove_assigned_users: Remove users added by this rule from the assigned group after deleting this resource. Default is `false`
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users_excludeds: The list of user IDs that would be excluded when rules are processed
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleState.__new__(_RuleState)

        __props__.__dict__["expression_type"] = expression_type
        __props__.__dict__["expression_value"] = expression_value
        __props__.__dict__["group_assignments"] = group_assignments
        __props__.__dict__["name"] = name
        __props__.__dict__["remove_assigned_users"] = remove_assigned_users
        __props__.__dict__["status"] = status
        __props__.__dict__["users_excludeds"] = users_excludeds
        return Rule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="expressionType")
    def expression_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The expression type to use to invoke the rule. The default is `urn:okta:expression:1.0`.
        """
        return pulumi.get(self, "expression_type")

    @_builtins.property
    @pulumi.getter(name="expressionValue")
    def expression_value(self) -> pulumi.Output[_builtins.str]:
        """
        The expression value.
        """
        return pulumi.get(self, "expression_value")

    @_builtins.property
    @pulumi.getter(name="groupAssignments")
    def group_assignments(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The list of group ids to assign the users to.
        """
        return pulumi.get(self, "group_assignments")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Group Rule (min character 1; max characters 50).
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="removeAssignedUsers")
    def remove_assigned_users(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Remove users added by this rule from the assigned group after deleting this resource. Default is `false`
        """
        return pulumi.get(self, "remove_assigned_users")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Default to `ACTIVE`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="usersExcludeds")
    def users_excludeds(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The list of user IDs that would be excluded when rules are processed
        """
        return pulumi.get(self, "users_excludeds")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, admin_roles=None, city=None, compound_search_operator=None, cost_center=None, country_code=None, custom_profile_attributes=None, delay_read_seconds=None, department=None, display_name=None, division=None, email=None, employee_number=None, first_name=None, group_memberships=None, honorific_prefix=None, honorific_suffix=None, id=None, last_name=None, locale=None, login=None, manager=None, manager_id=None, middle_name=None, mobile_phone=None, nick_name=None, organization=None, postal_address=None, preferred_language=None, primary_phone=None, profile_url=None, roles=None, searches=None, second_email=None, skip_groups=None, skip_roles=None, state=None, status=None, street_address=None, timezone=None, title=None, user_id=None, user_type=None, zip_code=None):
        if admin_roles and not isinstance(admin_roles, list):
            raise TypeError("Expected argument 'admin_roles' to be a list")
        pulumi.set(__self__, "admin_roles", admin_roles)
        if city and not isinstance(city, str):
            raise TypeError("Expected argument 'city' to be a str")
        pulumi.set(__self__, "city", city)
        if compound_search_operator and not isinstance(compound_search_operator, str):
            raise TypeError("Expected argument 'compound_search_operator' to be a str")
        pulumi.set(__self__, "compound_search_operator", compound_search_operator)
        if cost_center and not isinstance(cost_center, str):
            raise TypeError("Expected argument 'cost_center' to be a str")
        pulumi.set(__self__, "cost_center", cost_center)
        if country_code and not isinstance(country_code, str):
            raise TypeError("Expected argument 'country_code' to be a str")
        pulumi.set(__self__, "country_code", country_code)
        if custom_profile_attributes and not isinstance(custom_profile_attributes, str):
            raise TypeError("Expected argument 'custom_profile_attributes' to be a str")
        pulumi.set(__self__, "custom_profile_attributes", custom_profile_attributes)
        if delay_read_seconds and not isinstance(delay_read_seconds, str):
            raise TypeError("Expected argument 'delay_read_seconds' to be a str")
        pulumi.set(__self__, "delay_read_seconds", delay_read_seconds)
        if department and not isinstance(department, str):
            raise TypeError("Expected argument 'department' to be a str")
        pulumi.set(__self__, "department", department)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if division and not isinstance(division, str):
            raise TypeError("Expected argument 'division' to be a str")
        pulumi.set(__self__, "division", division)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if employee_number and not isinstance(employee_number, str):
            raise TypeError("Expected argument 'employee_number' to be a str")
        pulumi.set(__self__, "employee_number", employee_number)
        if first_name and not isinstance(first_name, str):
            raise TypeError("Expected argument 'first_name' to be a str")
        pulumi.set(__self__, "first_name", first_name)
        if group_memberships and not isinstance(group_memberships, list):
            raise TypeError("Expected argument 'group_memberships' to be a list")
        pulumi.set(__self__, "group_memberships", group_memberships)
        if honorific_prefix and not isinstance(honorific_prefix, str):
            raise TypeError("Expected argument 'honorific_prefix' to be a str")
        pulumi.set(__self__, "honorific_prefix", honorific_prefix)
        if honorific_suffix and not isinstance(honorific_suffix, str):
            raise TypeError("Expected argument 'honorific_suffix' to be a str")
        pulumi.set(__self__, "honorific_suffix", honorific_suffix)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_name and not isinstance(last_name, str):
            raise TypeError("Expected argument 'last_name' to be a str")
        pulumi.set(__self__, "last_name", last_name)
        if locale and not isinstance(locale, str):
            raise TypeError("Expected argument 'locale' to be a str")
        pulumi.set(__self__, "locale", locale)
        if login and not isinstance(login, str):
            raise TypeError("Expected argument 'login' to be a str")
        pulumi.set(__self__, "login", login)
        if manager and not isinstance(manager, str):
            raise TypeError("Expected argument 'manager' to be a str")
        pulumi.set(__self__, "manager", manager)
        if manager_id and not isinstance(manager_id, str):
            raise TypeError("Expected argument 'manager_id' to be a str")
        pulumi.set(__self__, "manager_id", manager_id)
        if middle_name and not isinstance(middle_name, str):
            raise TypeError("Expected argument 'middle_name' to be a str")
        pulumi.set(__self__, "middle_name", middle_name)
        if mobile_phone and not isinstance(mobile_phone, str):
            raise TypeError("Expected argument 'mobile_phone' to be a str")
        pulumi.set(__self__, "mobile_phone", mobile_phone)
        if nick_name and not isinstance(nick_name, str):
            raise TypeError("Expected argument 'nick_name' to be a str")
        pulumi.set(__self__, "nick_name", nick_name)
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        pulumi.set(__self__, "organization", organization)
        if postal_address and not isinstance(postal_address, str):
            raise TypeError("Expected argument 'postal_address' to be a str")
        pulumi.set(__self__, "postal_address", postal_address)
        if preferred_language and not isinstance(preferred_language, str):
            raise TypeError("Expected argument 'preferred_language' to be a str")
        pulumi.set(__self__, "preferred_language", preferred_language)
        if primary_phone and not isinstance(primary_phone, str):
            raise TypeError("Expected argument 'primary_phone' to be a str")
        pulumi.set(__self__, "primary_phone", primary_phone)
        if profile_url and not isinstance(profile_url, str):
            raise TypeError("Expected argument 'profile_url' to be a str")
        pulumi.set(__self__, "profile_url", profile_url)
        if roles and not isinstance(roles, list):
            raise TypeError("Expected argument 'roles' to be a list")
        pulumi.set(__self__, "roles", roles)
        if searches and not isinstance(searches, list):
            raise TypeError("Expected argument 'searches' to be a list")
        pulumi.set(__self__, "searches", searches)
        if second_email and not isinstance(second_email, str):
            raise TypeError("Expected argument 'second_email' to be a str")
        pulumi.set(__self__, "second_email", second_email)
        if skip_groups and not isinstance(skip_groups, bool):
            raise TypeError("Expected argument 'skip_groups' to be a bool")
        pulumi.set(__self__, "skip_groups", skip_groups)
        if skip_roles and not isinstance(skip_roles, bool):
            raise TypeError("Expected argument 'skip_roles' to be a bool")
        pulumi.set(__self__, "skip_roles", skip_roles)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if street_address and not isinstance(street_address, str):
            raise TypeError("Expected argument 'street_address' to be a str")
        pulumi.set(__self__, "street_address", street_address)
        if timezone and not isinstance(timezone, str):
            raise TypeError("Expected argument 'timezone' to be a str")
        pulumi.set(__self__, "timezone", timezone)
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        pulumi.set(__self__, "title", title)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)
        if user_type and not isinstance(user_type, str):
            raise TypeError("Expected argument 'user_type' to be a str")
        pulumi.set(__self__, "user_type", user_type)
        if zip_code and not isinstance(zip_code, str):
            raise TypeError("Expected argument 'zip_code' to be a str")
        pulumi.set(__self__, "zip_code", zip_code)

    @_builtins.property
    @pulumi.getter(name="adminRoles")
    def admin_roles(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "admin_roles")

    @_builtins.property
    @pulumi.getter
    def city(self) -> _builtins.str:
        return pulumi.get(self, "city")

    @_builtins.property
    @pulumi.getter(name="compoundSearchOperator")
    def compound_search_operator(self) -> Optional[_builtins.str]:
        """
        Search operator used when joining multiple search clauses
        """
        return pulumi.get(self, "compound_search_operator")

    @_builtins.property
    @pulumi.getter(name="costCenter")
    def cost_center(self) -> _builtins.str:
        return pulumi.get(self, "cost_center")

    @_builtins.property
    @pulumi.getter(name="countryCode")
    def country_code(self) -> _builtins.str:
        return pulumi.get(self, "country_code")

    @_builtins.property
    @pulumi.getter(name="customProfileAttributes")
    def custom_profile_attributes(self) -> _builtins.str:
        return pulumi.get(self, "custom_profile_attributes")

    @_builtins.property
    @pulumi.getter(name="delayReadSeconds")
    def delay_read_seconds(self) -> Optional[_builtins.str]:
        """
        Force delay of the user read by N seconds. Useful when eventual consistency of user information needs to be allowed for.
        """
        return pulumi.get(self, "delay_read_seconds")

    @_builtins.property
    @pulumi.getter
    def department(self) -> _builtins.str:
        return pulumi.get(self, "department")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def division(self) -> _builtins.str:
        return pulumi.get(self, "division")

    @_builtins.property
    @pulumi.getter
    def email(self) -> _builtins.str:
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter(name="employeeNumber")
    def employee_number(self) -> _builtins.str:
        return pulumi.get(self, "employee_number")

    @_builtins.property
    @pulumi.getter(name="firstName")
    def first_name(self) -> _builtins.str:
        return pulumi.get(self, "first_name")

    @_builtins.property
    @pulumi.getter(name="groupMemberships")
    def group_memberships(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "group_memberships")

    @_builtins.property
    @pulumi.getter(name="honorificPrefix")
    def honorific_prefix(self) -> _builtins.str:
        return pulumi.get(self, "honorific_prefix")

    @_builtins.property
    @pulumi.getter(name="honorificSuffix")
    def honorific_suffix(self) -> _builtins.str:
        return pulumi.get(self, "honorific_suffix")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastName")
    def last_name(self) -> _builtins.str:
        return pulumi.get(self, "last_name")

    @_builtins.property
    @pulumi.getter
    def locale(self) -> _builtins.str:
        return pulumi.get(self, "locale")

    @_builtins.property
    @pulumi.getter
    def login(self) -> _builtins.str:
        return pulumi.get(self, "login")

    @_builtins.property
    @pulumi.getter
    def manager(self) -> _builtins.str:
        return pulumi.get(self, "manager")

    @_builtins.property
    @pulumi.getter(name="managerId")
    def manager_id(self) -> _builtins.str:
        return pulumi.get(self, "manager_id")

    @_builtins.property
    @pulumi.getter(name="middleName")
    def middle_name(self) -> _builtins.str:
        return pulumi.get(self, "middle_name")

    @_builtins.property
    @pulumi.getter(name="mobilePhone")
    def mobile_phone(self) -> _builtins.str:
        return pulumi.get(self, "mobile_phone")

    @_builtins.property
    @pulumi.getter(name="nickName")
    def nick_name(self) -> _builtins.str:
        return pulumi.get(self, "nick_name")

    @_builtins.property
    @pulumi.getter
    def organization(self) -> _builtins.str:
        return pulumi.get(self, "organization")

    @_builtins.property
    @pulumi.getter(name="postalAddress")
    def postal_address(self) -> _builtins.str:
        return pulumi.get(self, "postal_address")

    @_builtins.property
    @pulumi.getter(name="preferredLanguage")
    def preferred_language(self) -> _builtins.str:
        return pulumi.get(self, "preferred_language")

    @_builtins.property
    @pulumi.getter(name="primaryPhone")
    def primary_phone(self) -> _builtins.str:
        return pulumi.get(self, "primary_phone")

    @_builtins.property
    @pulumi.getter(name="profileUrl")
    def profile_url(self) -> _builtins.str:
        return pulumi.get(self, "profile_url")

    @_builtins.property
    @pulumi.getter
    def roles(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "roles")

    @_builtins.property
    @pulumi.getter
    def searches(self) -> Optional[Sequence['outputs.GetUserSearchResult']]:
        """
        Filter to find user/users. Each filter will be concatenated with the compound search operator. Please be aware profile properties must match what is in Okta, which is likely camel case. Expression is a free form expression filter https://developer.okta.com/docs/reference/core-okta-api/#filter . The set name/value/comparison properties will be ignored if expression is present
        """
        return pulumi.get(self, "searches")

    @_builtins.property
    @pulumi.getter(name="secondEmail")
    def second_email(self) -> _builtins.str:
        return pulumi.get(self, "second_email")

    @_builtins.property
    @pulumi.getter(name="skipGroups")
    def skip_groups(self) -> Optional[_builtins.bool]:
        """
        Do not populate user groups information (prevents additional API call)
        """
        return pulumi.get(self, "skip_groups")

    @_builtins.property
    @pulumi.getter(name="skipRoles")
    def skip_roles(self) -> Optional[_builtins.bool]:
        """
        Do not populate user roles information (prevents additional API call)
        """
        return pulumi.get(self, "skip_roles")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="streetAddress")
    def street_address(self) -> _builtins.str:
        return pulumi.get(self, "street_address")

    @_builtins.property
    @pulumi.getter
    def timezone(self) -> _builtins.str:
        return pulumi.get(self, "timezone")

    @_builtins.property
    @pulumi.getter
    def title(self) -> _builtins.str:
        return pulumi.get(self, "title")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[_builtins.str]:
        """
        Retrieve a single user based on their id
        """
        return pulumi.get(self, "user_id")

    @_builtins.property
    @pulumi.getter(name="userType")
    def user_type(self) -> _builtins.str:
        return pulumi.get(self, "user_type")

    @_builtins.property
    @pulumi.getter(name="zipCode")
    def zip_code(self) -> _builtins.str:
        return pulumi.get(self, "zip_code")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            admin_roles=self.admin_roles,
            city=self.city,
            compound_search_operator=self.compound_search_operator,
            cost_center=self.cost_center,
            country_code=self.country_code,
            custom_profile_attributes=self.custom_profile_attributes,
            delay_read_seconds=self.delay_read_seconds,
            department=self.department,
            display_name=self.display_name,
            division=self.division,
            email=self.email,
            employee_number=self.employee_number,
            first_name=self.first_name,
            group_memberships=self.group_memberships,
            honorific_prefix=self.honorific_prefix,
            honorific_suffix=self.honorific_suffix,
            id=self.id,
            last_name=self.last_name,
            locale=self.locale,
            login=self.login,
            manager=self.manager,
            manager_id=self.manager_id,
            middle_name=self.middle_name,
            mobile_phone=self.mobile_phone,
            nick_name=self.nick_name,
            organization=self.organization,
            postal_address=self.postal_address,
            preferred_language=self.preferred_language,
            primary_phone=self.primary_phone,
            profile_url=self.profile_url,
            roles=self.roles,
            searches=self.searches,
            second_email=self.second_email,
            skip_groups=self.skip_groups,
            skip_roles=self.skip_roles,
            state=self.state,
            status=self.status,
            street_address=self.street_address,
            timezone=self.timezone,
            title=self.title,
            user_id=self.user_id,
            user_type=self.user_type,
            zip_code=self.zip_code)


def get_user(compound_search_operator: Optional[_builtins.str] = None,
             delay_read_seconds: Optional[_builtins.str] = None,
             searches: Optional[Sequence[Union['GetUserSearchArgs', 'GetUserSearchArgsDict']]] = None,
             skip_groups: Optional[_builtins.bool] = None,
             skip_roles: Optional[_builtins.bool] = None,
             user_id: Optional[_builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    Get a single users from Okta.


    :param _builtins.str compound_search_operator: Search operator used when joining multiple search clauses
    :param _builtins.str delay_read_seconds: Force delay of the user read by N seconds. Useful when eventual consistency of user information needs to be allowed for.
    :param Sequence[Union['GetUserSearchArgs', 'GetUserSearchArgsDict']] searches: Filter to find user/users. Each filter will be concatenated with the compound search operator. Please be aware profile properties must match what is in Okta, which is likely camel case. Expression is a free form expression filter https://developer.okta.com/docs/reference/core-okta-api/#filter . The set name/value/comparison properties will be ignored if expression is present
    :param _builtins.bool skip_groups: Do not populate user groups information (prevents additional API call)
    :param _builtins.bool skip_roles: Do not populate user roles information (prevents additional API call)
    :param _builtins.str user_id: Retrieve a single user based on their id
    """
    __args__ = dict()
    __args__['compoundSearchOperator'] = compound_search_operator
    __args__['delayReadSeconds'] = delay_read_seconds
    __args__['searches'] = searches
    __args__['skipGroups'] = skip_groups
    __args__['skipRoles'] = skip_roles
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:user/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        admin_roles=pulumi.get(__ret__, 'admin_roles'),
        city=pulumi.get(__ret__, 'city'),
        compound_search_operator=pulumi.get(__ret__, 'compound_search_operator'),
        cost_center=pulumi.get(__ret__, 'cost_center'),
        country_code=pulumi.get(__ret__, 'country_code'),
        custom_profile_attributes=pulumi.get(__ret__, 'custom_profile_attributes'),
        delay_read_seconds=pulumi.get(__ret__, 'delay_read_seconds'),
        department=pulumi.get(__ret__, 'department'),
        display_name=pulumi.get(__ret__, 'display_name'),
        division=pulumi.get(__ret__, 'division'),
        email=pulumi.get(__ret__, 'email'),
        employee_number=pulumi.get(__ret__, 'employee_number'),
        first_name=pulumi.get(__ret__, 'first_name'),
        group_memberships=pulumi.get(__ret__, 'group_memberships'),
        honorific_prefix=pulumi.get(__ret__, 'honorific_prefix'),
        honorific_suffix=pulumi.get(__ret__, 'honorific_suffix'),
        id=pulumi.get(__ret__, 'id'),
        last_name=pulumi.get(__ret__, 'last_name'),
        locale=pulumi.get(__ret__, 'locale'),
        login=pulumi.get(__ret__, 'login'),
        manager=pulumi.get(__ret__, 'manager'),
        manager_id=pulumi.get(__ret__, 'manager_id'),
        middle_name=pulumi.get(__ret__, 'middle_name'),
        mobile_phone=pulumi.get(__ret__, 'mobile_phone'),
        nick_name=pulumi.get(__ret__, 'nick_name'),
        organization=pulumi.get(__ret__, 'organization'),
        postal_address=pulumi.get(__ret__, 'postal_address'),
        preferred_language=pulumi.get(__ret__, 'preferred_language'),
        primary_phone=pulumi.get(__ret__, 'primary_phone'),
        profile_url=pulumi.get(__ret__, 'profile_url'),
        roles=pulumi.get(__ret__, 'roles'),
        searches=pulumi.get(__ret__, 'searches'),
        second_email=pulumi.get(__ret__, 'second_email'),
        skip_groups=pulumi.get(__ret__, 'skip_groups'),
        skip_roles=pulumi.get(__ret__, 'skip_roles'),
        state=pulumi.get(__ret__, 'state'),
        status=pulumi.get(__ret__, 'status'),
        street_address=pulumi.get(__ret__, 'street_address'),
        timezone=pulumi.get(__ret__, 'timezone'),
        title=pulumi.get(__ret__, 'title'),
        user_id=pulumi.get(__ret__, 'user_id'),
        user_type=pulumi.get(__ret__, 'user_type'),
        zip_code=pulumi.get(__ret__, 'zip_code'))
def get_user_output(compound_search_operator: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    delay_read_seconds: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    searches: Optional[pulumi.Input[Optional[Sequence[Union['GetUserSearchArgs', 'GetUserSearchArgsDict']]]]] = None,
                    skip_groups: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                    skip_roles: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                    user_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserResult]:
    """
    Get a single users from Okta.


    :param _builtins.str compound_search_operator: Search operator used when joining multiple search clauses
    :param _builtins.str delay_read_seconds: Force delay of the user read by N seconds. Useful when eventual consistency of user information needs to be allowed for.
    :param Sequence[Union['GetUserSearchArgs', 'GetUserSearchArgsDict']] searches: Filter to find user/users. Each filter will be concatenated with the compound search operator. Please be aware profile properties must match what is in Okta, which is likely camel case. Expression is a free form expression filter https://developer.okta.com/docs/reference/core-okta-api/#filter . The set name/value/comparison properties will be ignored if expression is present
    :param _builtins.bool skip_groups: Do not populate user groups information (prevents additional API call)
    :param _builtins.bool skip_roles: Do not populate user roles information (prevents additional API call)
    :param _builtins.str user_id: Retrieve a single user based on their id
    """
    __args__ = dict()
    __args__['compoundSearchOperator'] = compound_search_operator
    __args__['delayReadSeconds'] = delay_read_seconds
    __args__['searches'] = searches
    __args__['skipGroups'] = skip_groups
    __args__['skipRoles'] = skip_roles
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:user/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        admin_roles=pulumi.get(__response__, 'admin_roles'),
        city=pulumi.get(__response__, 'city'),
        compound_search_operator=pulumi.get(__response__, 'compound_search_operator'),
        cost_center=pulumi.get(__response__, 'cost_center'),
        country_code=pulumi.get(__response__, 'country_code'),
        custom_profile_attributes=pulumi.get(__response__, 'custom_profile_attributes'),
        delay_read_seconds=pulumi.get(__response__, 'delay_read_seconds'),
        department=pulumi.get(__response__, 'department'),
        display_name=pulumi.get(__response__, 'display_name'),
        division=pulumi.get(__response__, 'division'),
        email=pulumi.get(__response__, 'email'),
        employee_number=pulumi.get(__response__, 'employee_number'),
        first_name=pulumi.get(__response__, 'first_name'),
        group_memberships=pulumi.get(__response__, 'group_memberships'),
        honorific_prefix=pulumi.get(__response__, 'honorific_prefix'),
        honorific_suffix=pulumi.get(__response__, 'honorific_suffix'),
        id=pulumi.get(__response__, 'id'),
        last_name=pulumi.get(__response__, 'last_name'),
        locale=pulumi.get(__response__, 'locale'),
        login=pulumi.get(__response__, 'login'),
        manager=pulumi.get(__response__, 'manager'),
        manager_id=pulumi.get(__response__, 'manager_id'),
        middle_name=pulumi.get(__response__, 'middle_name'),
        mobile_phone=pulumi.get(__response__, 'mobile_phone'),
        nick_name=pulumi.get(__response__, 'nick_name'),
        organization=pulumi.get(__response__, 'organization'),
        postal_address=pulumi.get(__response__, 'postal_address'),
        preferred_language=pulumi.get(__response__, 'preferred_language'),
        primary_phone=pulumi.get(__response__, 'primary_phone'),
        profile_url=pulumi.get(__response__, 'profile_url'),
        roles=pulumi.get(__response__, 'roles'),
        searches=pulumi.get(__response__, 'searches'),
        second_email=pulumi.get(__response__, 'second_email'),
        skip_groups=pulumi.get(__response__, 'skip_groups'),
        skip_roles=pulumi.get(__response__, 'skip_roles'),
        state=pulumi.get(__response__, 'state'),
        status=pulumi.get(__response__, 'status'),
        street_address=pulumi.get(__response__, 'street_address'),
        timezone=pulumi.get(__response__, 'timezone'),
        title=pulumi.get(__response__, 'title'),
        user_id=pulumi.get(__response__, 'user_id'),
        user_type=pulumi.get(__response__, 'user_type'),
        zip_code=pulumi.get(__response__, 'zip_code')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ThreatInsightSettingsArgs', 'ThreatInsightSettings']

@pulumi.input_type
class ThreatInsightSettingsArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[_builtins.str],
                 network_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a ThreatInsightSettings resource.
        :param pulumi.Input[_builtins.str] action: Specifies how Okta responds to authentication requests from suspicious IPs. Valid values are `none`, `audit`, or `block`. A value of `none` indicates that ThreatInsight is disabled. A value of `audit` indicates that Okta logs suspicious requests in the System Log. A value of `block` indicates that Okta logs suspicious requests in the System Log and blocks the requests.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_excludes: Accepts a list of Network Zone IDs. Can only accept zones of `IP` type. IPs in the excluded Network Zones aren't logged or blocked by Okta ThreatInsight and proceed to Sign On rules evaluation. This ensures that traffic from known, trusted IPs isn't accidentally logged or blocked. The ordering of the network zone is not guarantee from the API sides
        """
        pulumi.set(__self__, "action", action)
        if network_excludes is not None:
            pulumi.set(__self__, "network_excludes", network_excludes)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies how Okta responds to authentication requests from suspicious IPs. Valid values are `none`, `audit`, or `block`. A value of `none` indicates that ThreatInsight is disabled. A value of `audit` indicates that Okta logs suspicious requests in the System Log. A value of `block` indicates that Okta logs suspicious requests in the System Log and blocks the requests.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter(name="networkExcludes")
    def network_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Accepts a list of Network Zone IDs. Can only accept zones of `IP` type. IPs in the excluded Network Zones aren't logged or blocked by Okta ThreatInsight and proceed to Sign On rules evaluation. This ensures that traffic from known, trusted IPs isn't accidentally logged or blocked. The ordering of the network zone is not guarantee from the API sides
        """
        return pulumi.get(self, "network_excludes")

    @network_excludes.setter
    def network_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "network_excludes", value)


@pulumi.input_type
class _ThreatInsightSettingsState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 network_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering ThreatInsightSettings resources.
        :param pulumi.Input[_builtins.str] action: Specifies how Okta responds to authentication requests from suspicious IPs. Valid values are `none`, `audit`, or `block`. A value of `none` indicates that ThreatInsight is disabled. A value of `audit` indicates that Okta logs suspicious requests in the System Log. A value of `block` indicates that Okta logs suspicious requests in the System Log and blocks the requests.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_excludes: Accepts a list of Network Zone IDs. Can only accept zones of `IP` type. IPs in the excluded Network Zones aren't logged or blocked by Okta ThreatInsight and proceed to Sign On rules evaluation. This ensures that traffic from known, trusted IPs isn't accidentally logged or blocked. The ordering of the network zone is not guarantee from the API sides
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if network_excludes is not None:
            pulumi.set(__self__, "network_excludes", network_excludes)

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies how Okta responds to authentication requests from suspicious IPs. Valid values are `none`, `audit`, or `block`. A value of `none` indicates that ThreatInsight is disabled. A value of `audit` indicates that Okta logs suspicious requests in the System Log. A value of `block` indicates that Okta logs suspicious requests in the System Log and blocks the requests.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter(name="networkExcludes")
    def network_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Accepts a list of Network Zone IDs. Can only accept zones of `IP` type. IPs in the excluded Network Zones aren't logged or blocked by Okta ThreatInsight and proceed to Sign On rules evaluation. This ensures that traffic from known, trusted IPs isn't accidentally logged or blocked. The ordering of the network zone is not guarantee from the API sides
        """
        return pulumi.get(self, "network_excludes")

    @network_excludes.setter
    def network_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "network_excludes", value)


@pulumi.type_token("okta:index/threatInsightSettings:ThreatInsightSettings")
class ThreatInsightSettings(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 network_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Manages Okta Threat Insight Settings. This resource allows you to configure Threat Insight Settings.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        ip_network_zone_example = okta.network.Zone("ip_network_zone_example",
            name="example",
            type="IP",
            gateways=[
                "1.2.3.4/24",
                "2.3.4.5-2.3.4.15",
            ],
            proxies=[
                "2.2.3.4/24",
                "3.3.4.5-3.3.4.15",
            ])
        example = okta.ThreatInsightSettings("example",
            action="block",
            network_excludes=[ip_network_zone_example.id])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/threatInsightSettings:ThreatInsightSettings example _
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: Specifies how Okta responds to authentication requests from suspicious IPs. Valid values are `none`, `audit`, or `block`. A value of `none` indicates that ThreatInsight is disabled. A value of `audit` indicates that Okta logs suspicious requests in the System Log. A value of `block` indicates that Okta logs suspicious requests in the System Log and blocks the requests.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_excludes: Accepts a list of Network Zone IDs. Can only accept zones of `IP` type. IPs in the excluded Network Zones aren't logged or blocked by Okta ThreatInsight and proceed to Sign On rules evaluation. This ensures that traffic from known, trusted IPs isn't accidentally logged or blocked. The ordering of the network zone is not guarantee from the API sides
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ThreatInsightSettingsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Okta Threat Insight Settings. This resource allows you to configure Threat Insight Settings.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        ip_network_zone_example = okta.network.Zone("ip_network_zone_example",
            name="example",
            type="IP",
            gateways=[
                "1.2.3.4/24",
                "2.3.4.5-2.3.4.15",
            ],
            proxies=[
                "2.2.3.4/24",
                "3.3.4.5-3.3.4.15",
            ])
        example = okta.ThreatInsightSettings("example",
            action="block",
            network_excludes=[ip_network_zone_example.id])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/threatInsightSettings:ThreatInsightSettings example _
        ```

        :param str resource_name: The name of the resource.
        :param ThreatInsightSettingsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ThreatInsightSettingsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 network_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ThreatInsightSettingsArgs.__new__(ThreatInsightSettingsArgs)

            if action is None and not opts.urn:
                raise TypeError("Missing required property 'action'")
            __props__.__dict__["action"] = action
            __props__.__dict__["network_excludes"] = network_excludes
        super(ThreatInsightSettings, __self__).__init__(
            'okta:index/threatInsightSettings:ThreatInsightSettings',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[_builtins.str]] = None,
            network_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'ThreatInsightSettings':
        """
        Get an existing ThreatInsightSettings resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: Specifies how Okta responds to authentication requests from suspicious IPs. Valid values are `none`, `audit`, or `block`. A value of `none` indicates that ThreatInsight is disabled. A value of `audit` indicates that Okta logs suspicious requests in the System Log. A value of `block` indicates that Okta logs suspicious requests in the System Log and blocks the requests.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_excludes: Accepts a list of Network Zone IDs. Can only accept zones of `IP` type. IPs in the excluded Network Zones aren't logged or blocked by Okta ThreatInsight and proceed to Sign On rules evaluation. This ensures that traffic from known, trusted IPs isn't accidentally logged or blocked. The ordering of the network zone is not guarantee from the API sides
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ThreatInsightSettingsState.__new__(_ThreatInsightSettingsState)

        __props__.__dict__["action"] = action
        __props__.__dict__["network_excludes"] = network_excludes
        return ThreatInsightSettings(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies how Okta responds to authentication requests from suspicious IPs. Valid values are `none`, `audit`, or `block`. A value of `none` indicates that ThreatInsight is disabled. A value of `audit` indicates that Okta logs suspicious requests in the System Log. A value of `block` indicates that Okta logs suspicious requests in the System Log and blocks the requests.
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="networkExcludes")
    def network_excludes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Accepts a list of Network Zone IDs. Can only accept zones of `IP` type. IPs in the excluded Network Zones aren't logged or blocked by Okta ThreatInsight and proceed to Sign On rules evaluation. This ensures that traffic from known, trusted IPs isn't accidentally logged or blocked. The ordering of the network zone is not guarantee from the API sides
        """
        return pulumi.get(self, "network_excludes")

